==> gnunet-gtk-0.9.2.tar.gz: gnunet-gtk-0.9.2/src/setup/gnunet-setup-datacache-plugins.c <==
/*
     This file is part of GNUnet.
     (C) 2010 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

/**
 * @file src/gnunet-setup-datacache-plugins.c
 * @brief (de)sensitize transport plugin buttons based on plugin availability
 * @author Christian Grothoff
 */
#include "gnunet-setup.h"


/**
 * Test if the given plugin exists and change the sensitivity
 * of the widget accordingly.
 *
 * @param widget widget to update
 * @param name name of the plugin to check
 */
static void
test_plugin (GtkWidget * widget, const char *name)
{
  if (GNUNET_YES == GNUNET_PLUGIN_test (name))
  {
    gtk_widget_set_sensitive (widget, TRUE);
  }
  else
  {
    gtk_widget_set_sensitive (widget, FALSE);
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
  }
}



void
GNUNET_setup_fs_datacache_sqlite_radiobutton_realize_cb (GtkWidget * widget,
                                                         gpointer user_data)
{
  test_plugin (widget, "libgnunet_plugin_datacache_sqlite");
}


void
GNUNET_setup_fs_datacache_mysql_radiobutton_realize_cb (GtkWidget * widget,
                                                        gpointer user_data)
{
  test_plugin (widget, "libgnunet_plugin_datacache_mysql");
}


void
GNUNET_setup_fs_datacache_postgres_radiobutton_realize_cb (GtkWidget * widget,
                                                           gpointer user_data)
{
  test_plugin (widget, "libgnunet_plugin_datacache_postgres");
}



/* end of gnunet-setup-transport-plugins.c */

==> gnunet-gtk_0.9.5.orig.tar.gz: gnunet-gtk-0.9.5/src/setup/gnunet-setup-datacache-plugins.c <==
/*
     This file is part of GNUnet.
     (C) 2010 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

/**
 * @file src/gnunet-setup-datacache-plugins.c
 * @brief (de)sensitize transport plugin buttons based on plugin availability
 * @author Christian Grothoff
 */
#include "gnunet-setup.h"


/**
 * Test if the given plugin exists and change the sensitivity
 * of the widget accordingly.
 *
 * @param widget widget to update
 * @param name name of the plugin to check
 */
static void
test_plugin (GtkWidget * widget, const char *name)
{
  if (GNUNET_YES == GNUNET_PLUGIN_test (name))
  {
    gtk_widget_set_sensitive (widget, TRUE);
  }
  else
  {
    gtk_widget_set_sensitive (widget, FALSE);
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
  }
}



void
GNUNET_setup_fs_datacache_sqlite_radiobutton_realize_cb (GtkWidget * widget,
                                                         gpointer user_data)
{
  test_plugin (widget, "libgnunet_plugin_datacache_sqlite");
}


void
GNUNET_setup_fs_datacache_heap_radiobutton_realize_cb (GtkWidget * widget,
                                                        gpointer user_data)
{
  test_plugin (widget, "libgnunet_plugin_datacache_heap");
}


void
GNUNET_setup_fs_datacache_postgres_radiobutton_realize_cb (GtkWidget * widget,
                                                           gpointer user_data)
{
  test_plugin (widget, "libgnunet_plugin_datacache_postgres");
}



/* end of gnunet-setup-transport-plugins.c */
